Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(308)

Unified Diff: pkg/compiler/lib/src/types/map_type_mask.dart

Issue 2976483002: Further cleanup of element use in type_graph_nodes (Closed)
Patch Set: Updated cf. comment Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/compiler/lib/src/types/dictionary_type_mask.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/types/map_type_mask.dart
diff --git a/pkg/compiler/lib/src/types/map_type_mask.dart b/pkg/compiler/lib/src/types/map_type_mask.dart
index 4fe6a79393d810e5de3830916bcb65f386923f3c..5152b9d217b3fa942405d549f6702fd9d3f67e07 100644
--- a/pkg/compiler/lib/src/types/map_type_mask.dart
+++ b/pkg/compiler/lib/src/types/map_type_mask.dart
@@ -15,8 +15,8 @@ class MapTypeMask extends ForwardingTypeMask {
// The [Node] where this type mask was created.
final Node allocationNode;
- // The [Entity] where this type mask was created.
- final Entity allocationElement;
+ // The [MemberEntity] where this type mask was created.
+ final MemberEntity allocationElement;
// The value type of this map.
final TypeMask valueType;
« no previous file with comments | « pkg/compiler/lib/src/types/dictionary_type_mask.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698